@@ -1,4 +1,4 @@
-/* Copyright 2007-2009,2011,2014,2020,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007-2009,2011,2014,2020,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -56,7 +56,7 @@
 /**                # Version 6.1  : from : 05 apr 2021     **/
 /**                                 to   : 18 dec 2021     **/
 /**                # Version 7.0  : from : 03 sep 2020     **/
-/**                                 to   : 18 dec 2021     **/
+/**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -64,8 +64,6 @@
 ** The defines and includes.
 */
 
-#define DGRAPH_HALO
-
 #include "module.h"
 #include "common.h"
 #include "dgraph.h"
