@@ -1,4 +1,4 @@
-/* Copyright 2008,2011,2014,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2008,2011,2014,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -48,7 +48,7 @@
 /**                # Version 6.1  : from : 28 jun 2021     **/
 /**                                 to   : 28 jun 2021     **/
 /**                # Version 7.0  : from : 03 may 2021     **/
-/**                                 to   : 29 oct 2021     **/
+/**                                 to   : 20 jan 2023     **/
 /**                                                        **/
 /**   NOTES      : # This is a rewrite of kgraphMapRb()    **/
 /**                  for complete-graph target topologies. **/
@@ -64,7 +64,7 @@
 **  The defines and includes.
 */
 
-#define KGRAPH_MAP_RB_PART
+#define SCOTCH_KGRAPH_MAP_RB_PART
 
 #include "module.h"
 #include "common.h"
