@@ -43,7 +43,7 @@
 /**                # Version 5.0  : from : 26 jul 2007     **/
 /**                                 to   : 26 jul 2007     **/
 /**                # Version 7.0  : from : 20 jan 2023     **/
-/**                                 to   : 20 jan 2023     **/
+/**                                 to   : 10 aug 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -78,16 +78,25 @@ Gnum * const                      treenbr)
 {
   if (cblkptr->vnodnbr < 1) {
     errorPrint ("orderCheck2: invalid number of vertex nodes (1)");
-    return     (1);
+    return (1);
   }
 
   if (cblkptr->cblktab != NULL) {                 /* If node has sons */
     Gnum                vnodnbr;
     Gnum                cblknum;
 
-    if (cblkptr->cblknbr <= 0) {
+    if ((cblkptr->typeval != ORDERCBLKNEDI) &&
+        (cblkptr->typeval != ORDERCBLKDICO) &&
+        (cblkptr->typeval != ORDERCBLKSEQU)) {
+      errorPrint ("orderCheck2: invalid node type (1)");
+      return (1);
+    }
+    if ((cblkptr->cblknbr <= 0) ||
+        ((cblkptr->typeval == ORDERCBLKNEDI) &&
+         ((cblkptr->cblknbr < 2) ||
+          (cblkptr->cblknbr > 3)))) {
       errorPrint ("orderCheck2: invalid number of column blocks (1)");
-      return     (1);
+      return (1);
     }
     *cblknbr += cblkptr->cblknbr - 1;
     *treenbr += cblkptr->cblknbr;
@@ -98,12 +107,18 @@ Gnum * const                      treenbr)
     }
     if (vnodnbr != cblkptr->vnodnbr) {
       errorPrint ("orderCheck2: invalid number of vertex nodes (2)");
-      return     (1);
+      return (1);
     }
   }
-  else if (cblkptr->cblknbr != 0) {
-    errorPrint ("orderCheck2: invalid number of column blocks (2)");
-    return     (1);
+  else {
+    if (cblkptr->typeval != ORDERCBLKLEAF) {
+      errorPrint ("orderCheck2: invalid node type (2)");
+      return (1);
+    }
+    if (cblkptr->cblknbr != 0) {
+      errorPrint ("orderCheck2: invalid number of column blocks (2)");
+      return (1);
+    }
   }
 
   return (0);
@@ -122,16 +137,16 @@ const Order * restrict const  ordeptr)
 
   if (ordeptr->vnodnbr != ordeptr->cblktre.vnodnbr) {
     errorPrint ("orderCheck: invalid vertex count");
-    return     (1);
+    return (1);
   }
   if ((ordeptr->cblknbr < 0) || (ordeptr->cblknbr > ordeptr->treenbr)) {
     errorPrint ("orderCheck: invalid column block count (1)");
-    return     (1);
+    return (1);
   }
 
   if ((permtab = (Gnum *) memAlloc (ordeptr->vnodnbr * sizeof (Gnum))) == NULL) {
     errorPrint ("orderCheck: out of memory");
-    return     (1);
+    return (1);
   }
   memSet (permtab, ~0, ordeptr->cblktre.vnodnbr * sizeof (Gnum));
   permtax = permtab - ordeptr->baseval;
@@ -142,12 +157,12 @@ const Order * restrict const  ordeptr)
         (ordeptr->peritab[vertnum] >= vertnnd)) {
       errorPrint ("orderCheck: invalid index");
       memFree    (permtab);
-      return     (1);
+      return (1);
     }
     if (permtax[ordeptr->peritab[vertnum]] != ~0) { /* If index already used */
       errorPrint ("orderCheck: duplicate index");
       memFree    (permtab);
-      return     (1);
+      return (1);
     }
     permtax[ordeptr->peritab[vertnum]] = vertnum; /* Set who updated index */
   }
@@ -155,7 +170,7 @@ const Order * restrict const  ordeptr)
     if (permtab[vertnum] == ~0) {                 /* If index not used */
       errorPrint ("orderCheck: missing index");
       memFree    (permtab);
-      return     (1);
+      return (1);
     }
   }
 
@@ -167,12 +182,12 @@ const Order * restrict const  ordeptr)
     return (1);
   if (cblknbr != ordeptr->cblknbr) {
     errorPrint ("orderCheck: invalid number of column blocks");
-    return     (1);
+    return (1);
   }
   if (treenbr != ordeptr->treenbr) {
     errorPrint ("orderCheck: invalid number of tree nodes");
-    return     (1);
+    return (1);
   }
 
-  return  (0);
+  return (0);
 }
