@@ -361,12 +361,5 @@ abort :                                           /* If overflow occured, resume
   }
 #endif /* SCOTCH_DEBUG_VDGRAPH2 */
 
-if (grafptr->s.proclocnum == 0)
-fprintf (stderr, "BROL " GNUMSTRING "," GNUMSTRING "," GNUMSTRING "(" GNUMSTRING ")\n",
-         (Gnum) grafptr->compglbload[0],
-         (Gnum) grafptr->compglbload[1],
-         (Gnum) grafptr->compglbload[2],
-         (Gnum) grafptr->compglbloaddlt);
-
   return (0);
 }
