@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2012,2018,2019,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2012,2018,2019,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -54,7 +54,7 @@
 /**                # Version 6.1  : from : 21 nov 2021     **/
 /**                                 to   : 21 nov 2021     **/
 /**                # Version 7.0  : from : 12 sep 2019     **/
-/**                                 to   : 13 sep 2019     **/
+/**                                 to   : 16 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -62,8 +62,6 @@
 **  The defines and includes.
 */
 
-#define VGRAPH_SEPARATE_GG
-
 #include "module.h"
 #include "common.h"
 #include "gain.h"
