@@ -44,7 +44,7 @@
 /**                # Version 6.0  : from : 13 sep 2012     **/
 /**                                 to   : 18 may 2019     **/
 /**                # Version 7.0  : from : 21 jan 2023     **/
-/**                                 to   : 21 jan 2023     **/
+/**                                 to   : 30 jun 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -81,12 +81,15 @@ const float * const         ubvec,                          \
 const SCOTCH_Num * const    options,                        \
 SCOTCH_Num * const          edgecut,                        \
 SCOTCH_Num * const          part,                           \
-MPI_Comm * const            commptr,                        \
+const MPI_Fint * const      commptr,                        \
 int * const                 revaptr),                       \
 (vtxdist, xadj, adjncy, vwgt, adjwgt, wgtflag, numflag, ncon, nparts, tpwgts, ubvec, options, edgecut, part, commptr, revaptr))
 {
+  MPI_Comm            commdat;
+
+  commdat = MPI_Comm_f2c (*commptr);
   *revaptr = SCOTCH_ParMETIS_V3_PartKway (vtxdist, xadj, adjncy, vwgt, adjwgt, wgtflag, numflag,
-                                          ncon, nparts, tpwgts, ubvec, options, edgecut, part, commptr);
+                                          ncon, nparts, tpwgts, ubvec, options, edgecut, part, &commdat);
 }
 
 /*
@@ -111,12 +114,15 @@ const float * const         ubvec,                                  \
 const SCOTCH_Num * const    options,                                \
 SCOTCH_Num * const          edgecut,                                \
 SCOTCH_Num * const          part,                                   \
-MPI_Comm * const            commptr,                                \
+const MPI_Fint * const      commptr,                                \
 int * const                 revaptr),                               \
 (vtxdist, xadj, adjncy, vwgt, adjwgt, wgtflag, numflag, ndims, xyz, ncon, nparts, tpwgts, ubvec, options, edgecut, part, commptr, revaptr))
 {
+  MPI_Comm            commdat;
+
+  commdat = MPI_Comm_f2c (*commptr);
   *revaptr = SCOTCH_ParMETIS_V3_PartGeomKway (vtxdist, xadj, adjncy, vwgt, adjwgt, wgtflag, numflag,
-                                              ndims, xyz, ncon, nparts, tpwgts, ubvec, options, edgecut, part, commptr);
+                                              ndims, xyz, ncon, nparts, tpwgts, ubvec, options, edgecut, part, &commdat);
 }
 
 /*******************/
@@ -144,10 +150,13 @@ const float * const         ubvec,                                      \
 const SCOTCH_Num * const    options,                                    \
 SCOTCH_Num * const          edgecut,                                    \
 SCOTCH_Num * const          part,                                       \
-MPI_Comm * const            commptr),                                   \
+const MPI_Fint * const      commptr),                                   \
 (vtxdist, xadj, adjncy, vwgt, adjwgt, wgtflag, numflag, ncon, nparts, tpwgts, ubvec, options, edgecut, part, commptr))
 {
-  METISNAMEU (ParMETIS_V3_PartKway) (vtxdist, xadj, adjncy, vwgt, adjwgt, wgtflag, numflag, ncon, nparts, tpwgts, ubvec, options, edgecut, part, commptr);
+  MPI_Comm            commdat;
+
+  commdat = MPI_Comm_f2c (*commptr);
+  METISNAMEU (ParMETIS_V3_PartKway) (vtxdist, xadj, adjncy, vwgt, adjwgt, wgtflag, numflag, ncon, nparts, tpwgts, ubvec, options, edgecut, part, &commdat);
 }
 
 /*
@@ -172,10 +181,13 @@ const float * const         ubvec,
 const SCOTCH_Num * const    options,                                            \
 SCOTCH_Num * const          edgecut,                                            \
 SCOTCH_Num * const          part,                                               \
-MPI_Comm * const            commptr),                                           \
+const MPI_Fint * const      commptr),                                           \
 (vtxdist, xadj, adjncy, vwgt, adjwgt, wgtflag, numflag, ndims, xyz, ncon, nparts, tpwgts, ubvec, options, edgecut, part, commptr))
 {
-  METISNAMEU (ParMETIS_V3_PartGeomKway) (vtxdist, xadj, adjncy, vwgt, adjwgt, wgtflag, numflag, ndims, xyz, ncon, nparts, tpwgts, ubvec, options, edgecut, part, commptr);
+  MPI_Comm            commdat;
+
+  commdat = MPI_Comm_f2c (*commptr);
+  METISNAMEU (ParMETIS_V3_PartGeomKway) (vtxdist, xadj, adjncy, vwgt, adjwgt, wgtflag, numflag, ndims, xyz, ncon, nparts, tpwgts, ubvec, options, edgecut, part, &commdat);
 }
 
 #endif /* SCOTCH_METIS_PREFIX */
