@@ -46,7 +46,7 @@
 /**                # Version 6.0  : from : 01 jan 2012     **/
 /**                                 to   : 17 apr 2019     **/
 /**                # Version 7.0  : from : 03 sep 2020     **/
-/**                                 to   : 21 jan 2023     **/
+/**                                 to   : 03 jul 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -144,8 +144,8 @@ char *                      argv[])
   MPI_Op              reduop;
   int                 i, j;
 #ifdef SCOTCH_PTHREAD_MPI
-  int                 thrdlvlreqval;
-  int                 thrdlvlproval;
+  int                 thrdreqlvl;
+  int                 thrdprolvl;
 #endif /* SCOTCH_PTHREAD_MPI */
 
   flagval = C_FLAGNONE;                           /* Default behavior  */
@@ -163,11 +163,9 @@ char *                      argv[])
 #endif /* SCOTCH_COMPILE_PART */
 
 #ifdef SCOTCH_PTHREAD_MPI
-  thrdlvlreqval = MPI_THREAD_MULTIPLE;
-  if (MPI_Init_thread (&argc, &argv, thrdlvlreqval, &thrdlvlproval) != MPI_SUCCESS)
+  thrdreqlvl = MPI_THREAD_MULTIPLE;
+  if (MPI_Init_thread (&argc, &argv, thrdreqlvl, &thrdprolvl) != MPI_SUCCESS)
     errorPrint ("main: Cannot initialize (1)");
-  if (thrdlvlreqval > thrdlvlproval)
-    errorPrint ("main: MPI implementation is not thread-safe: recompile without SCOTCH_PTHREAD_MPI");
 #else /* SCOTCH_PTHREAD_MPI */
   if (MPI_Init (&argc, &argv) != MPI_SUCCESS)
     errorPrint ("main: Cannot initialize (2)");
