@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010-2012,2014,2018,2019,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010-2012,2014,2018,2019,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -60,6 +60,8 @@
 /**                                 to   : 17 apr 2019     **/
 /**                # Version 6.1  : from : 04 apr 2021     **/
 /**                                 to   : 28 aug 2021     **/
+/**                # Version 7.0  : from : 31 aug 2021     **/
+/**                                 to   : 21 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -67,8 +69,6 @@
 **  The defines and includes
 */
 
-#define GOUT
-
 #include "module.h"
 #include "common.h"
 #include "scotch.h"
@@ -131,7 +131,7 @@ static const char *         C_usageList[] = {     /* Usage */
   "                          v        : view cut edges",
   "  -V                  : Print program version and copyright",
   "",
-  "Default option set is : -Oi{c,v}",
+  "Default option set is : -Ov{v}",
   NULL };
 
 /*****************************/
